;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "circe" "20251013.1911"
  "Client for IRC in Emacs."
  '((emacs  "25.1")
    (cl-lib "0.5"))
  :url "https://github.com/emacs-circe/circe"
  :commit "e909ff49e59c396b19564855a3f282684a4e716e"
  :revdesc "e909ff49e59c"
  :keywords '("irc" "chat" "comm")
  :authors '(("Jorgen Schaefer" . "forcer@forcix.cx"))
  :maintainers '(("Jorgen Schaefer" . "forcer@forcix.cx")))
